=== modified file 'deelistmodel.cpp'
--- deelistmodel.cpp	2011-01-24 00:28:12 +0000
+++ deelistmodel.cpp	2011-01-24 00:59:39 +0000
@@ -34,7 +34,10 @@
 {
     if (m_dee_model != NULL) {
         /* Disconnect from all GObject properties */
-        g_object_disconnect(m_dee_model, "any_signal", G_CALLBACK(onReadyStatic), this, NULL);
+        g_object_disconnect(m_dee_model, "any_signal", G_CALLBACK(onReady), this, NULL);
+        g_object_disconnect(m_dee_model, "any_signal", G_CALLBACK(onRowAdded), this, NULL);
+        g_object_disconnect(m_dee_model, "any_signal", G_CALLBACK(onRowRemoved), this, NULL);
+        g_object_disconnect(m_dee_model, "any_signal", G_CALLBACK(onRowChanged), this, NULL);
 
         g_object_unref(m_dee_model);
         m_dee_model = NULL;
@@ -81,7 +84,10 @@
     {
         m_dee_model = dee_shared_model_new_with_name(m_name.toUtf8().data());
         /* FIXME: connect to row-added, row-changed and row-removed signals */
-        g_signal_connect(m_dee_model, "ready", G_CALLBACK(onReadyStatic), this);
+        g_signal_connect(m_dee_model, "ready", G_CALLBACK(onReady), this);
+        g_signal_connect(m_dee_model, "row-added", G_CALLBACK(onRowAdded), this);
+        g_signal_connect(m_dee_model, "row-removed", G_CALLBACK(onRowRemoved), this);
+        g_signal_connect(m_dee_model, "row-changed", G_CALLBACK(onRowChanged), this);
         dee_shared_model_connect(DEE_SHARED_MODEL(m_dee_model));
     }
 }
@@ -179,9 +185,36 @@
 }
 
 
-void DeeListModel::onReadyStatic(GObject *gobject __attribute__ ((unused)),
-                                 DeeListModel *model)
+void DeeListModel::onReady(GObject* emitter __attribute__ ((unused)),
+                           DeeListModel *model)
 {
     model->createRoles();
     model->setReady(true);
 }
+
+void DeeListModel::onRowAdded(GObject *emitter __attribute__ ((unused)),
+                              DeeModelIter* iter,
+                              DeeListModel* model)
+{
+    gint position = dee_model_get_position(model->m_dee_model, iter);
+    model->beginInsertRows(QModelIndex(), position, position);
+    model->endInsertRows();
+}
+
+void DeeListModel::onRowRemoved(GObject *emitter __attribute__ ((unused)),
+                                DeeModelIter* iter,
+                                DeeListModel* model)
+{
+    gint position = dee_model_get_position(model->m_dee_model, iter);
+    model->beginRemoveRows(QModelIndex(), position, position);
+    model->endRemoveRows();
+}
+
+void DeeListModel::onRowChanged(GObject *emitter __attribute__ ((unused)),
+                                DeeModelIter* iter,
+                                DeeListModel* model)
+{
+    gint position = dee_model_get_position(model->m_dee_model, iter);
+    QModelIndex index = model->index(position);
+    Q_EMIT model->dataChanged(index, index);
+}

=== modified file 'deelistmodel.h'
--- deelistmodel.h	2011-01-24 00:28:12 +0000
+++ deelistmodel.h	2011-01-24 00:59:39 +0000
@@ -53,12 +53,17 @@
     void createRoles();
 
 private:
-    static void onReadyStatic(GObject *gobject, DeeListModel *model);
     void connect();
 
     /* setters */
     void setReady(bool ready);
 
+    /* GObject signal handlers for m_dee_model */
+    static void onReady(GObject* emitter, DeeListModel* model);
+    static void onRowAdded(GObject* emitter, DeeModelIter* iter, DeeListModel* model);
+    static void onRowRemoved(GObject* emitter, DeeModelIter* iter, DeeListModel* model);
+    static void onRowChanged(GObject* emitter, DeeModelIter* iter, DeeListModel* model);
+
     DeeModel* m_dee_model;
     QString m_name;
     bool m_ready;

=== modified file 'test.cpp'
--- test.cpp	2011-01-24 00:28:12 +0000
+++ test.cpp	2011-01-24 00:59:39 +0000
@@ -27,6 +27,8 @@
     DeeListModel* model = new DeeListModel;
 
     QObject::connect(model, SIGNAL(readyChanged(bool)), &application, SLOT(onReadyChanged(bool)));
+    QObject::connect(model, SIGNAL(rowsInserted(QModelIndex, int, int)), &application, SLOT(onRowsInserted()));
+
     model->setName("com.canonical.Unity.ApplicationsPlace.ResultsModel");
 
     return application.exec();

=== modified file 'test.h'
--- test.h	2011-01-24 00:28:12 +0000
+++ test.h	2011-01-24 00:59:39 +0000
@@ -42,6 +42,11 @@
             qDebug() << model->data(model->index(i));
         }
     }
+
+    void onRowsInserted() {
+        DeeListModel* model = (DeeListModel*)sender();
+        qDebug() << "Rows added, current number:" << model->rowCount();
+    }
 };
 
 #endif // TEST_H

=== modified file 'test.qml'
--- test.qml	2010-11-22 07:54:25 +0000
+++ test.qml	2011-01-24 00:59:39 +0000
@@ -9,7 +9,6 @@
         text: column_0
     }
     model: DeeListModel {
-        objectPath: "/com/canonical/dee/model/com/canonical/Unity/ApplicationsPlace/SectionsModel"
-        service: "com.canonical.Unity.ApplicationsPlace"
+        name: "com.canonical.Unity.ApplicationsPlace.SectionsModel"
     }
 }

